build

package
v1.2.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Cleanup

func Cleanup(pluginPaths []string) error

Cleanup removes the temporary build directory containing the plugins. The caller should defer this to ensure cleanup.

func Scripts

func Scripts(scriptDirs []string) ([]string, error)

Scripts compiles Go scripts as plugins and returns their paths. Each script directory must have a go.mod file.

Types

This section is empty.

Jump to